@@ -4,7 +4,7 @@
  * GChemPaint library
  * application.cc 
  *
- * Copyright (C) 2004-2005 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2006 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -22,16 +22,6 @@
  * USA
  */
 
-#ifndef HAS_OPENBABEL_2
-#	include <mol.h>
-#	undef PACKAGE
-#	undef PACKAGE_BUGREPORT
-#	undef PACKAGE_NAME
-#	undef PACKAGE_STRING
-#	undef PACKAGE_TARNAME
-#	undef PACKAGE_VERSION
-#	undef VERSION
-#endif
 #include "gchempaint-config.h"
 #include "application.h"
 #include "document.h"
@@ -47,6 +37,8 @@
 #include "reactant.h"
 #include "reaction-step.h"
 #include "reaction-arrow.h"
+#include "tools.h"
+#include "zoomdlg.h"
 #include <bonobo/bonobo-ui-util.h>
 #include <sys/stat.h>
 #include <gconf/gconf-client.h>
@@ -54,12 +46,8 @@
 #include <libgnomevfs/gnome-vfs-ops.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <locale.h>
-#ifdef HAS_OPENBABEL_2
-#	include <openbabel/mol.h>
-#	include <openbabel/obconversion.h>
-#else
-#	include <sstream>
-#endif
+#include <openbabel/mol.h>
+#include <openbabel/obconversion.h>
 
 // Objects creation static methods
 static Object* CreateMolecule()
@@ -115,9 +103,14 @@ static Object* CreateFragment()
 list<gcpApplication*> Apps;
 bool	gcpApplication::m_bInit = false;
 bool	gcpApplication::m_Have_Ghemical = false;
+bool	gcpApplication::m_Have_InChI = false;
 map<string, string> gcpApplication::m_SupportedPixbufFormats;
 
-gcpApplication::gcpApplication ()
+#warning "the following lines should be removed for stable releases"
+#undef PACKAGE
+#define PACKAGE "gchempaint-unstable" 
+
+gcpApplication::gcpApplication (): Application (PACKAGE, DATADIR)
 {
 	Apps.push_back(this);
 	m_CurZ = 6;
@@ -129,12 +122,12 @@ gcpApplication::gcpApplication ()
 	GConfClient* cli = gconf_client_get_default ();
 	if (cli) {
 		const char *value;
-		GConfEntry* entry = gconf_client_get_entry (cli, "/desktop/gnome/applications/help_viewer/exec", NULL, true, NULL);
+/*		GConfEntry* entry = gconf_client_get_entry (cli, "/desktop/gnome/applications/help_viewer/exec", NULL, true, NULL);
 		if (entry) {
 			value = gconf_value_get_string (gconf_entry_get_value (entry));
 			if (value) HelpBrowser = value;
-		}
-		entry = gconf_client_get_entry (cli, "/desktop/gnome/applications/browser/exec", NULL, true, NULL);
+		}*/
+		GConfEntry* entry = gconf_client_get_entry (cli, "/desktop/gnome/applications/browser/exec", NULL, true, NULL);
 		if (entry) {
 			value = gconf_value_get_string (gconf_entry_get_value (entry));
 			if (value) WebBrowser = value;
@@ -145,14 +138,14 @@ gcpApplication::gcpApplication ()
 			if (value) {
 				MailAgent = value;
 				int i = MailAgent.find (" %s");
-				if (i > 0)
+				if (i)
 					MailAgent.erase (i, MailAgent.size ());
 			}
 		}
 	}
 
 	// search help file
-	string lang = getenv ("LANG");
+/*	string lang = getenv ("LANG");
 	HelpFilename = string (DATADIR"/gnome/help/") + string (PACKAGE"/") + lang + "/"PACKAGE".xml";
 	struct stat buf;
 	int err = stat(HelpFilename.c_str (), &buf);
@@ -170,7 +163,7 @@ gcpApplication::gcpApplication ()
 	if (err) {
 		g_warning("Help file not found");
 		HelpFilename = "";
-	}
+	}*/
 
 	if (!m_bInit) {
 		// Check for programs
@@ -178,6 +171,18 @@ gcpApplication::gcpApplication ()
 		// check for ghemical
 		m_Have_Ghemical = (g_spawn_command_line_sync ("which ghemical", &result, &errors, NULL, NULL)
 			&& result && strlen (result));
+		if (result) {
+			g_free (result);
+			result = NULL;
+		}
+		if (errors) {
+			g_free (errors);
+			errors = NULL;
+		}
+		OBConversion Conv;
+		m_Have_InChI = Conv.FindFormat ("inchi") != NULL || 
+			(g_spawn_command_line_sync ("which main_inchi", &result, &errors, NULL, NULL)
+			&& result && strlen (result));
 		if (result)
 			g_free (result);
 		if (errors) {
@@ -238,9 +243,15 @@ gcpApplication::gcpApplication ()
 		gcpPlugin::LoadPlugins();
 		m_bInit = true;
 	}
+	RadioActions = NULL;
+	m_entries = 0;
+	IconFactory = gtk_icon_factory_new ();
 	set<gcpPlugin*>::iterator i = Plugins.begin (), end = Plugins.end ();
 	while (i != end) (*i++)->Populate (this);
+	gtk_icon_factory_add_default (IconFactory);
+	g_object_unref (G_OBJECT (IconFactory));
 	XmlDoc = xmlNewDoc ((xmlChar const*) "1.0");
+	visible_windows = 0;
 }
 
 gcpApplication::~gcpApplication()
@@ -305,7 +316,7 @@ void gcpApplication::AddUI (const char* filename)
 	else 
 	{
 		BonoboUINode *Child, *Next;
-		if (!strcmp(bonobo_ui_node_get_name (Parent), "Root"))
+		if (!strcmp (bonobo_ui_node_get_name (Parent), "Root"))
 			Node = bonobo_ui_node_children (Parent);
 		else
 			Node = NULL;
@@ -428,25 +439,11 @@ bool gcpApplication::FileProcess(const gchar* filename, int filetype, bool bSave
 		{
 			// destroy the old file
 			gnome_vfs_unlink (filename2);
-#ifdef HAS_OPENBABEL_2
 			pDoc->SetType (filetype);
 			if (filetype == gcp_ft_Normal)
 				SaveGcp (filename2, pDoc);
 			else
 				SaveWithBabel (filename2, ext, pDoc, filetype);
-#else
-			switch(filetype)
-			{
-				case gcp_ft_Normal:
-					pDoc->SetType(UNDEFINED);
-					SaveGcp(filename2, pDoc);
-					break;
-				case gcp_ft_CML: SaveWithBabel(filename2, ext, pDoc, CML); break;
-				case gcp_ft_SDF: SaveWithBabel(filename2, ext, pDoc, SDF); break;
-				case gcp_ft_PDB: SaveWithBabel(filename2, ext, pDoc, PDB); break;
-				case gcp_ft_ChemDraw: SaveWithBabel(filename2, ext, pDoc, CHEMDRAW); break;
-			}
-#endif
 		}
 	}
 	else //loading
@@ -514,21 +511,10 @@ bool gcpApplication::FileProcess(const gchar* filename, int filetype, bool bSave
 			}
 		}
 		else filename2 = g_strdup(filename);
-#ifdef HAS_OPENBABEL_2
 		if (filetype == gcp_ft_Normal)
 			OpenGcp (filename2, pDoc);
 		else
 			OpenWithBabel (filename2, ext, pDoc, filetype);
-#else
-		switch (filetype)
-		{
-			case gcp_ft_Normal: OpenGcp(filename2, pDoc); break;
-			case gcp_ft_CML: OpenWithBabel(filename2, ext, pDoc, CML); break;
-			case gcp_ft_SDF: OpenWithBabel(filename2, ext, pDoc, SDF); break;
-			case gcp_ft_PDB: OpenWithBabel(filename2, ext, pDoc, PDB); break;
-			case gcp_ft_ChemDraw: OpenWithBabel(filename2, ext, pDoc, CHEMDRAW); break;
-		}
-#endif
 	}
 	g_free(filename2);
 	return false;
@@ -564,17 +550,11 @@ void gcpApplication::OpenWithBabel(const gchar* filename, const gchar* ext, gcpD
 			if (!ifs) throw (int) 1;
 			old_num_locale = g_strdup (setlocale (LC_NUMERIC, NULL));
 			setlocale(LC_NUMERIC, "C");
-#ifdef HAS_OPENBABEL_2
 			OBMol Mol;
 			OBConversion Conv;
 			OBFormat* pInFormat = Conv.FormatFromExt (filename);
 			Conv.SetInAndOutFormats (pInFormat, pInFormat);
 			Conv.Read (&Mol, &ifs);
-#else
-			OBMol Mol ((io_type) Type);
-			OBFileFormat fileFormat;
-			fileFormat.ReadMolecule (ifs, Mol);
-#endif
 			result = pDoc->ImportOB(Mol);
 			setlocale (LC_NUMERIC, old_num_locale);
 			g_free (old_num_locale);
@@ -587,17 +567,11 @@ void gcpApplication::OpenWithBabel(const gchar* filename, const gchar* ext, gcpD
 			istringstream iss (buf);
 			old_num_locale = g_strdup (setlocale (LC_NUMERIC, NULL));
 			setlocale(LC_NUMERIC, "C");
-#ifdef HAS_OPENBABEL_2
 			OBMol Mol;
 			OBConversion Conv;
 			OBFormat* pInFormat = Conv.FormatFromExt (filename);
 			Conv.SetInAndOutFormats (pInFormat, pInFormat);
 			Conv.Read (&Mol, &iss);
-#else
-			OBMol Mol ((io_type) Type);
-			OBFileFormat fileFormat;
-			fileFormat.ReadMolecule (iss, Mol);
-#endif
 			result = pDoc->ImportOB(Mol);
 			setlocale (LC_NUMERIC, old_num_locale);
 			setlocale (LC_NUMERIC, old_num_locale);
@@ -763,20 +737,6 @@ void gcpApplication::InitTools()
 			(*i).second->Activate ((*i).first == "Select");
 }
 
-void gcpApplication::OnHelp (char* tag)
-{
-	if (!HelpBrowser.size () || !HelpFilename.size ())
-		return;
-	char *argv[3] = {NULL, NULL, NULL};
-	argv[0] = (char*) HelpBrowser.c_str();
-	string path = HelpFilename;
-	if (tag)
-		path += string("#") + string (PACKAGE) + string ("-") + string (tag);
-	argv[1] = (char*) path.c_str ();
-	g_spawn_async (NULL, argv, NULL, G_SPAWN_SEARCH_PATH,
-		NULL, NULL, NULL, NULL);
-}
-
 void gcpApplication::OnBug ()
 {
 	if (!WebBrowser.size ())
@@ -787,6 +747,17 @@ void gcpApplication::OnBug ()
 		NULL, NULL, NULL, NULL);
 }
 
+void gcpApplication::ShowURI (string& uri)
+{
+	if (!WebBrowser.size ())
+		return;
+	char *argv[3] = {NULL, NULL, NULL};
+	argv[0] = (char*) WebBrowser.c_str();
+	argv[1] = (char*) uri.c_str ();
+	g_spawn_async (NULL, argv, NULL, G_SPAWN_SEARCH_PATH,
+		NULL, NULL, NULL, NULL);
+}
+
 void gcpApplication::OnWeb ()
 {
 	if (!WebBrowser.size ())
@@ -889,3 +860,146 @@ void gcpApplication::SetCurDir (char const* dir)
 		g_free (CurDir);
 	CurDir = g_strdup (dir);
 }
+
+void gcpApplication::Zoom (double zoom)
+{
+	gcpView *pView = m_pActiveDoc->GetView ();
+	// authorized zooms: 20% to 800% all other values will open the zoom dialog.
+	if (zoom >= 0.2 && zoom <= 8.)
+		pView->Zoom (zoom);
+	else {
+		Dialog *pDialog = GetDialog ("Zoom");
+		if (pDialog)
+			gtk_window_present (pDialog->GetWindow ()); 
+		else
+			new gcpZoomDlg (this);
+	}
+}
+
+static void on_tool_changed (GtkAction *action, GtkAction *current, gcpApplication* App)
+{
+	App->OnToolChanged (current);
+}
+
+void gcpApplication::OnToolChanged (GtkAction *current)
+{
+	if (m_pActiveTool)
+		m_pActiveTool->Activate(false);
+	m_pActiveTool = Tools[gtk_action_get_name (current)];
+	if (m_pActiveTool)
+		m_pActiveTool->Activate(true);
+	gcpTools *Tools = dynamic_cast<gcpTools*> (Dialogs["Tools"]);
+	if (Tools)
+		Tools->OnSelectTool (m_pActiveTool);		
+}
+
+void gcpApplication::BuildTools ()
+{
+	gcpTools *ToolsBox = new gcpTools (this);
+	map<int, string>::iterator i, iend = ToolbarNames.end ();
+	list<char const*>::iterator j, jend = UiDescs.end ();
+	string s;
+	GError *error = NULL;
+	GtkUIManager *ToolsManager = gtk_ui_manager_new ();
+	ToolsBox->SetUIManager (ToolsManager);
+	GtkActionGroup *action_group = gtk_action_group_new ("Tools");
+	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
+	gtk_action_group_add_radio_actions (action_group, RadioActions, m_entries, 0, G_CALLBACK (on_tool_changed), this);
+	gtk_ui_manager_insert_action_group (ToolsManager, action_group, 0);
+	for (j = UiDescs.begin (); j != jend; j++)
+		if (!gtk_ui_manager_add_ui_from_string (ToolsManager, *j, -1, &error)) {
+			g_message ("building user interface failed: %s", error->message);
+			g_error_free (error);
+			exit (EXIT_FAILURE);
+		}
+	for (i = ToolbarNames.begin (); i != iend; i++) {
+		s = "ui/";
+		s += (*i).second;
+		ToolsBox->AddToolbar (s);
+	}
+	g_object_unref (ToolsManager);
+	m_pActiveTool = Tools["Select"];
+	if (m_pActiveTool)
+		m_pActiveTool->Activate(true);
+	ToolsBox->OnSelectTool (m_pActiveTool);		
+	gcpMendeleievDlg::SetElement (this, m_CurZ);
+}
+
+void gcpApplication::ShowTools (bool visible)
+{
+	gcpTools *Tools = dynamic_cast<gcpTools*> (Dialogs["Tools"]);
+	if (!Tools) {
+		if (visible)
+			BuildTools ();
+	} else
+	Tools->Show (visible);
+}
+
+void gcpApplication::AddActions (GtkRadioActionEntry const *entries, int nb, char const *ui_description, gcpIconDesc const *icons)
+{
+	static int cur_entry = 1;
+	if (nb > 0) {
+		if (m_entries)
+			RadioActions = g_renew (GtkRadioActionEntry, RadioActions, m_entries + nb);
+		else
+			RadioActions = g_new (GtkRadioActionEntry, nb);
+		memcpy (RadioActions + m_entries, entries, nb * sizeof (GtkRadioActionEntry));
+		for (int i = 0; i < nb; i++)
+			if (strcmp (RadioActions[i + m_entries].name, "Select"))
+				RadioActions[i + m_entries].value = cur_entry++;
+			else
+				RadioActions[i + m_entries].value = 0;
+		m_entries += nb;
+	}
+	if (ui_description)
+		UiDescs.push_back (ui_description);
+	if (icons) {
+		GtkIconSet *set;
+		GtkIconSource *src;
+		while (icons->name) {
+			set = gtk_icon_set_new ();
+			src = gtk_icon_source_new ();
+		
+			gtk_icon_source_set_size_wildcarded (src, TRUE);
+			gtk_icon_source_set_pixbuf (src,
+				gdk_pixbuf_new_from_inline (-1, icons->data_24, FALSE, NULL));
+			gtk_icon_set_add_source (set, src);	/* copies the src */
+		
+			gtk_icon_factory_add (IconFactory, icons->name, set);	/* keeps reference to set */
+			gtk_icon_set_unref (set);
+			gtk_icon_source_free (src);
+			icons++;
+		}
+	}
+}
+
+void gcpApplication::RegisterToolbar (char const *name, int index)
+{
+	if (ToolbarNames[index] == "")
+		ToolbarNames[index] = name;
+}
+
+void gcpApplication::AddWindow (gcpWindow *window)
+{
+	m_Windows.insert (window);
+	NotifyIconification (false);
+}
+
+void gcpApplication::DeleteWindow (gcpWindow *window)
+{
+	m_Windows.erase (window);
+	NotifyIconification (true);
+}
+
+void gcpApplication::NotifyIconification (bool iconified)
+{
+	if (iconified) {
+		visible_windows--;
+		if (visible_windows == 0)
+			ShowTools (false);
+	} else {
+		if (visible_windows == 0)
+			ShowTools (true);
+		visible_windows++;
+	}
+}
