@@ -36,7 +36,7 @@
 class gcpDocument;
 class gcpWidgetData;
 
-#define GCHEMPAINT_ATOM_NAME "application/gchempaint"
+#define GCHEMPAINT_ATOM_NAME "application/x-gchempaint"
 extern GtkTargetEntry const targets[];
 
 class gcpView
@@ -76,7 +76,7 @@ public:
 	void OnCutSelection(GtkWidget* w, GtkClipboard* clipboard);
 	bool OnKeyPress(GtkWidget* w, GdkEventKey* event);
 	bool OnKeyRelease(GtkWidget* w, GdkEventKey* event);
-	bool OnSize(int width, int height);
+	bool OnSize (GtkWidget *w, int width, int height);
 	void UpdateSize(double x1, double y1, double x2, double y2);
 	void SetGnomeCanvasRichTextActive(GnomeCanvasRichTextExt* item);
 	bool PrepareUnselect();
@@ -89,6 +89,7 @@ public:
 	double GetStoichiometryPadding () {return m_StoichiometryPadding;}
 	double GetBaseLineOffset () {return m_BaseLineOffset;}
 	void EnsureSize ();
+	void Zoom (double zoom);
 
 	//Implementation
 private:
