@@ -208,7 +208,7 @@ void gcpWidgetData::Copy(GtkClipboard* clipboard)
 	std::list<Object*>::iterator i;
 	xmlNodePtr child;
 	for (i = SelectedObjects.begin(); i != SelectedObjects.end(); i++)
-		if ((child = (*i)->Save(pXmlDoc))) xmlAddChild((*pDoc)->children, child);
+		if (child = (*i)->Save(pXmlDoc)) xmlAddChild((*pDoc)->children, child);
 	gcpApplication* App = View->GetDoc()->GetApplication();
 	gtk_clipboard_set_with_data(clipboard, targets, 2, (GtkClipboardGetFunc)on_get_data, (GtkClipboardClearFunc)on_clear_data, App);
 	gtk_clipboard_request_contents(clipboard, gdk_atom_intern ("TARGETS", FALSE),  (GtkClipboardReceivedFunc)on_receive_targets, App);
