@@ -67,7 +67,8 @@ public:
 
 	void SetSize(unsigned char size);
 	unsigned char GetSize() {return m_size;}
-	virtual void SetOptions();
+	void SetOptions();
+	GtkWidget *GetPropertyPage ();
 };
 
 #endif	//GCHEMPAINT_CYCLE_TOOL_H
