@@ -4,9 +4,7 @@
  * GChemPaint templates plugin
  * plugin.cc 
  *
- * Copyright (C) 2004
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -29,6 +27,7 @@
 #include "lib/application.h"
 #include "templatetool.h"
 #include "templatetree.h"
+#include <glib/gi18n-lib.h>
 #include <sys/stat.h>
 
 gcpTemplatesPlugin plugin;
@@ -45,7 +44,7 @@ gcpTemplatesPlugin::gcpTemplatesPlugin(): gcpPlugin()
 	xmlIndentTreeOutput = true;
 	xmlKeepBlanksDefault (0);
 	if (dir) {
-		while ((name = g_dir_read_name (dir))) {
+		while (name = g_dir_read_name (dir)) {
 			if (strcmp (name + strlen (name) - 4, ".xml")) continue;
 			name = g_strconcat (DATADIR"/gchempaint/templates/", name, NULL);
 			doc = xmlParseFile (name);
@@ -60,7 +59,7 @@ gcpTemplatesPlugin::gcpTemplatesPlugin(): gcpPlugin()
 	dir = g_dir_open (path, 0, NULL);
 	if (dir) {
 		bool is_user_templates;
-		while ((name = g_dir_read_name (dir))) {
+		while (name = g_dir_read_name (dir)) {
 			if (strcmp (name + strlen (name) - 4, ".xml")) continue;
 			is_user_templates = !strcmp (name, "templates.xml");
 			name = g_strconcat (path, "/", name, NULL);
@@ -99,9 +98,28 @@ gcpTemplatesPlugin::~gcpTemplatesPlugin()
 	TempbyName.clear ();
 }
 
+static GtkRadioActionEntry entries[] = {
+	{	"Templates", GTK_STOCK_INDEX, N_("Templates"), NULL,
+		N_("Use or manage templates"),
+		0	},
+};
+
+static const char *ui_description =
+"<ui>"
+"  <toolbar name='SelectToolbar'>"
+"	 <placeholder name='Select1'/>"
+"	 <placeholder name='Select2'>"
+"	   <separator/>"
+"	   <toolitem action='Templates'/>"
+"	 </placeholder>"
+"	 <placeholder name='Select3'/>"
+"  </toolbar>"
+"</ui>";
+
 void gcpTemplatesPlugin::Populate (gcpApplication* App)
 {
-	App->AddUI (DATADIR"/gchempaint/ui/templates.xml");
+	App->AddUI (DATADIR"/gchempaint-unstable/ui/templates.xml");
+	App->AddActions (entries, G_N_ELEMENTS (entries), ui_description, NULL);
 	new gcpTemplateTool (App);
 	new gcpTemplateTree (App);
 }
