@@ -29,7 +29,7 @@
 
 xmlDocPtr xml;
 
-class gcpNewTemplateToolDlg: public gcpDialog
+class gcpNewTemplateToolDlg: public Dialog
 {
 public:
 	gcpNewTemplateToolDlg(gcpApplication* App);
@@ -110,7 +110,7 @@ void gcpTemplateTool::OnRelease()
 	pDoc->FinishOperation ();
 }
 
-class gcpTemplateToolDlg: public gcpDialog
+class gcpTemplateToolDlg: public Dialog
 {
 public:
 	gcpTemplateToolDlg(gcpApplication* App, gcpTemplate* t);
@@ -168,7 +168,7 @@ static void on_delete_template (GtkWidget *w, gcpTemplateToolDlg *dlg)
 	dlg->OnDeleteTemplate ();
 }
 
-gcpTemplateToolDlg::gcpTemplateToolDlg(gcpApplication* App, gcpTemplate *t): gcpDialog(App, GLADEDIR"/templates.glade", "templates")
+gcpTemplateToolDlg::gcpTemplateToolDlg(gcpApplication* App, gcpTemplate *t): Dialog(App, DATADIR"/gchempaint-unstable/ui/templates.glade", "templates")
 {
 	tree = (gcpTemplateTree*) App->GetTool ("TemplateTree");
 	if (!tree) {delete this; return;}
@@ -184,7 +184,7 @@ gcpTemplateToolDlg::gcpTemplateToolDlg(gcpApplication* App, gcpTemplate *t): gcp
 								NULL);
 	g_signal_connect (G_OBJECT(Selection), "changed", G_CALLBACK (on_changed), this);
 	temp = t;
-	pDoc = new gcpDocument(m_App, true);
+	pDoc = new gcpDocument(reinterpret_cast<gcpApplication*> (m_App), true);
 	pDoc->SetEditable (false);
 	GtkWidget* w;
 	GtkScrolledWindow* scroll = (GtkScrolledWindow*)glade_xml_get_widget(xml, "scrolledcanvas");
@@ -216,12 +216,13 @@ gcpTemplateToolDlg::gcpTemplateToolDlg(gcpApplication* App, gcpTemplate *t): gcp
 
 gcpTemplateToolDlg::~gcpTemplateToolDlg()
 {
-	m_App->SetDialog("Templates", NULL);
+	reinterpret_cast<gcpApplication*> (m_App)->SetDialog("Templates", NULL);
 }
 
 bool gcpTemplateToolDlg::Apply()
 {
-	gcpTemplateTool* tool = (gcpTemplateTool*) m_App->GetTool ("Templates");
+	gcpTemplateTool* tool = (gcpTemplateTool*)
+			reinterpret_cast<gcpApplication*> (m_App)->GetTool ("Templates");
 	tool->SetTemplate (temp);
 	tree->SetTemplate (temp);
 	return true;
@@ -240,14 +241,14 @@ void gcpTemplateToolDlg::OnChanged(GtkTreeSelection *Selection)
 		gtk_tree_path_free (path);
 		map<string, Object*>::iterator it;
 		Object* obj;
-		while ((obj = pDoc->GetFirstChild(it))) {
+		while (obj = pDoc->GetFirstChild(it)) {
 			pDoc->Remove (obj);
 			pDoc->PopOperation ();
 		}
 		if (temp) {
 			pDoc->AddData (temp->node);
 			pData->UnselectAll ();
-			pDoc->GetView () ->OnSize (0, 0);
+			pDoc->GetView ()->OnSize (pDoc->GetWidget (), 0, 0);
 			g_signal_emit_by_name (G_OBJECT (pDoc->GetWidget ()), "update_bounds");
 			gtk_widget_set_sensitive (glade_xml_get_widget (xml, "delete"), temp->writeable);
 		}
@@ -258,17 +259,19 @@ void gcpTemplateToolDlg::OnChanged(GtkTreeSelection *Selection)
 
 void gcpTemplateToolDlg::OnAddTemplate ()
 {
-	gcpNewTemplateToolDlg* dlg = (gcpNewTemplateToolDlg*) m_App->GetDialog("New Template");
+	gcpNewTemplateToolDlg* dlg = (gcpNewTemplateToolDlg*)
+			reinterpret_cast<gcpApplication*> (m_App)->GetDialog("New Template");
 	if (!dlg)
 	{
-		dlg = new gcpNewTemplateToolDlg (m_App);
+		dlg = new gcpNewTemplateToolDlg (reinterpret_cast<gcpApplication*> (m_App));
 	}
 	else gdk_window_raise (GTK_WIDGET(dlg->GetWindow())->window); 
 }
 
 void gcpTemplateToolDlg::OnDeleteTemplate ()
 {
-	gcpTemplateTool* tool = (gcpTemplateTool*) m_App->GetTool ("Templates");
+	gcpTemplateTool* tool = (gcpTemplateTool*)
+			reinterpret_cast<gcpApplication*> (m_App)->GetTool ("Templates");
 	if (temp == tool->GetTemplate()) {
 		tool->SetTemplate (NULL);
 		tree->SetTemplate (NULL);
@@ -294,7 +297,8 @@ void gcpTemplateToolDlg::OnDeleteTemplate ()
 
 void gcpTemplateToolDlg::SetTemplate (gcpTemplate* t)
 {
-	tree = (gcpTemplateTree*) m_App->GetTool ("TemplateTree");
+	tree = (gcpTemplateTree*)
+			reinterpret_cast<gcpApplication*> (m_App)->GetTool ("TemplateTree");
 	if (tree && t) {
 	GtkTreeView* view = (GtkTreeView*)glade_xml_get_widget(xml, "template_tree_view");
 	GtkTreeSelection* Selection = gtk_tree_view_get_selection(view);
@@ -308,15 +312,15 @@ void gcpTemplateToolDlg::SetTemplate (gcpTemplate* t)
 	}
 }
 
-gcpNewTemplateToolDlg::gcpNewTemplateToolDlg(gcpApplication* App): gcpDialog(App, GLADEDIR"/new-template.glade", "new_template")
+gcpNewTemplateToolDlg::gcpNewTemplateToolDlg(gcpApplication* App): Dialog(App, DATADIR"/gchempaint-unstable/ui/new-template.glade", "new_template")
 {
-	pDoc = new gcpDocument(m_App, true);
+	pDoc = new gcpDocument(reinterpret_cast<gcpApplication*> (m_App), true);
 	pDoc->SetEditable (false);
 	GtkWidget* w;
 	GtkScrolledWindow* scroll = (GtkScrolledWindow*)glade_xml_get_widget(xml, "scrolledcanvas");
 	gtk_scrolled_window_add_with_viewport(scroll, w = pDoc->GetWidget());
 	pData = (gcpWidgetData*) g_object_get_data (G_OBJECT (w), "data");
-	m_App->SetDialog("New Template", this);
+	reinterpret_cast<gcpApplication*> (m_App)->SetDialog("New Template", this);
 	m_node = NULL;
 	/* build the categories list */
 	GtkListStore *model = gtk_list_store_new (NUM_COLUMNS, G_TYPE_STRING);
@@ -337,7 +341,7 @@ gcpNewTemplateToolDlg::gcpNewTemplateToolDlg(gcpApplication* App): gcpDialog(App
 
 gcpNewTemplateToolDlg::~gcpNewTemplateToolDlg()
 {
-	m_App->SetDialog("New Template", NULL);
+	reinterpret_cast<gcpApplication*> (m_App)->SetDialog("New Template", NULL);
 	if (m_node){
 		xmlUnlinkNode (m_node);
 		xmlFreeNode (m_node);
@@ -413,10 +417,12 @@ bool gcpNewTemplateToolDlg::Apply()
 	xmlIndentTreeOutput = true;
 	xmlKeepBlanksDefault (0);
 	xmlSaveFormatFile((char*) user_templates->URL, user_templates, true);
-	gcpTemplateTree *tree = (gcpTemplateTree*) m_App->GetTool ("TemplateTree");
+	gcpTemplateTree *tree = (gcpTemplateTree*)
+			reinterpret_cast<gcpApplication*> (m_App)->GetTool ("TemplateTree");
 	if (tree)
 		tree->AddTemplate (key);
-	gcpTemplateToolDlg *dlg = (gcpTemplateToolDlg*) m_App->GetDialog ("Templates");
+	gcpTemplateToolDlg *dlg = (gcpTemplateToolDlg*)
+			reinterpret_cast<gcpApplication*> (m_App)->GetDialog ("Templates");
 	if (dlg) {
 		dlg->SetTemplate (temp);
 	}
