@@ -4,9 +4,7 @@
  * GChemPaint
  * gchempaint-bonobo.cc 
  *
- * Copyright (C) 2001-2003
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2003 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -174,8 +172,8 @@ static void set_prop (BonoboPropertyBag *bag,  const BonoboArg *arg, guint arg_i
 			{
 				gcpDocument* pDoc = (gcpDocument*) g_object_get_data(G_OBJECT(widget), "doc");
 				if (pDoc) pDoc->SetEditable(BONOBO_ARG_GET_BOOLEAN(arg));
-			}*/
-			break;
+			}
+			break;*/
 		default:
 			bonobo_exception_set(ev, ex_Bonobo_PropertyBag_NotFound);
 			break;
